# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import datetime
import sys

from pathlib import Path


# support package imports
basedir = Path(__file__).resolve().parent.parent / "src"
sys.path.insert(0, str(basedir))


# -- Project information -----------------------------------------------------

project = "ahriman"
copyright = f"2021-{datetime.date.today().year}, ahriman team"
author = "ahriman team"

# The full version, including alpha/beta/rc tags
from ahriman import __version__
release = __version__


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named "sphinx.ext.*") or your custom
# ones.
extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.graphviz",
    "sphinx.ext.napoleon",
    "sphinx_rtd_theme",
    "sphinxarg.ext",
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = "en"

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "sphinx_rtd_theme"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]

html_logo = "_static/logo.svg"

add_module_names = False

modindex_common_prefix = [
    "ahriman.application.",
    "ahriman.core.",
    "ahriman.models.",
    "ahriman.web.",
]


# -- Extension configuration -------------------------------------------------

autoclass_content = "both"

autodoc_member_order = "groupwise"

autodoc_mock_imports = [
    "aioauth_client",
    "aiohttp_security",
    "aiohttp_session",
    "cryptography", 
    "pyalpm",
]

autodoc_default_options = {
    "no-undoc-members": True,
}

graphviz_output_format = "svg"
