#
# Copyright (c) 2021-2025 ahriman team.
#
# This file is part of ahriman
# (see https://github.com/arcan1s/ahriman).
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
#
from dataclasses import dataclass
from typing import Generic, Self, TypeVar


T = TypeVar("T")


@dataclass(frozen=True)
class ContextKey(Generic[T]):
    """
    ahriman context key for typing purposes

    Attributes:
        key(str): context key to lookup
        return_type(type[T]): return type used for the specified context key
    """
    key: str
    return_type: type[T]

    @classmethod
    def from_type(cls, return_type: type[T]) -> Self:
        """
        construct key from type

        Args:
            return_type(type[T]): return type used for the specified context key

        Returns:
            Self: context key with autogenerated
        """
        return cls(return_type.__name__, return_type)
